/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.syslogng.bean;


/**
 * リポジトリ更新用トピックの定義を定数として格納するクラス<BR>
 *
 * @version 2.0.0
 * @since 2.0.0
 */
public class TopicConstant {
	
    /** リポジトリ更新用トピック名。 */
    public static final String TOPIC_NAME_EXECUTE = "topic/clustercontrolRepositoryUpdate";
}
